Brightway2-UI
=============

This is a web and command line user interface, part of the `Brightway2 LCA framework <http://brightwaylca.org>`_. The source code is hosted on `Bitucket <https://bitbucket.org/cmutel/brightway2-ui>`_.
